Index: src/utils/SkTextureCompressor.h |
diff --git a/src/utils/SkTextureCompressor.h b/src/utils/SkTextureCompressor.h |
index e35bc957ac2c9ee783b30e2caa33070f6077e81a..e31a5ab48d5262168dc0bdf11c400e0a64065167 100644 |
--- a/src/utils/SkTextureCompressor.h |
+++ b/src/utils/SkTextureCompressor.h |
@@ -55,10 +55,10 @@ namespace SkTextureCompressor { |
int GetCompressedDataSize(Format fmt, int width, int height); |
// Returns an SkData holding a blob of compressed data that corresponds |
// to the bitmap. If the bitmap colorType cannot be compressed using the |
// associated format, then we return NULL. The caller is responsible for |
// calling unref() on the returned data. |
- SkData* CompressBitmapToFormat(const SkBitmap& bitmap, Format format); |
+ SkData* CompressBitmapToFormat(const SkPixmap&, Format format); |
// Compresses the given src data into dst. The src data is assumed to be |
// large enough to hold width*height pixels. The dst data is expected to |
@@ -55,10 +55,10 @@ namespace SkTextureCompressor { |
int GetCompressedDataSize(Format fmt, int width, int height); |
// Returns an SkData holding a blob of compressed data that corresponds |
- // to the bitmap. If the bitmap colorType cannot be compressed using the |
+ // to the pixmap. If the pixmap colorType cannot be compressed using the |
// associated format, then we return NULL. The caller is responsible for |
// calling unref() on the returned data. |